pitcharraytools.PitchArrayColumn
================================

.. abjad-lineage:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn

.. autoclass:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.append
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.cell_tokens
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.cell_widths
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.cells
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.column_index
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.depth
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.dimensions
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.extend
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.has_voice_crossing
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.is_defective
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.parent_array
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.pitches
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.remove_pitches
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.start_cells
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.start_pitches
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.stop_cells
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.stop_pitches
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.weight
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.width
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__eq__
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__format__
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__getitem__
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__ne__
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__repr__
      ~abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.cell_tokens
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.cell_widths
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.cells
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.column_index
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.depth
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.dimensions
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.has_voice_crossing
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.is_defective
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.parent_array
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.pitches
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.start_cells
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.start_pitches
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.stop_cells
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.stop_pitches
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.weight
   :noindex:

.. autoattribute:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.width
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.append
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.extend
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.remove_pitches
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__eq__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__format__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__ne__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__repr__
   :noindex:

.. automethod:: abjad.tools.pitcharraytools.PitchArrayColumn.PitchArrayColumn.__str__
   :noindex:
